# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v2/get_daily_scalar.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:systemathics/apis/services/daily/v2/get_daily_scalar.proto\x12#systemathics.apis.services.daily.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xf1\x01\n\x12\x44\x61ilyScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12U\n\x0e\x64\x61te_intervals\x18\x03 \x03(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\rdateIntervals\x12\x1e\n\nadjustment\x18\x04 \x01(\x08R\nadjustment\"\xa7\x02\n\x13\x44\x61ilyScalarResponse\x12\'\n\x05\x64\x61tes\x18\x01 \x03(\x0b\x32\x11.google.type.DateR\x05\x64\x61tes\x12i\n\x0b\x66ields_data\x18\x02 \x03(\x0b\x32H.systemathics.apis.services.daily.v2.DailyScalarResponse.FieldsDataEntryR\nfieldsData\x1a|\n\x0f\x46ieldsDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12S\n\x05value\x18\x02 \x01(\x0b\x32=.systemathics.apis.services.daily.v2.DailyScalarValueResponseR\x05value:\x02\x38\x01\".\n\x18\x44\x61ilyScalarValueResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x03(\x01R\x04\x64\x61ta\"\xcc\x01\n\x19\x44\x61ilyScalarStreamResponse\x12R\n\x04info\x18\x01 \x01(\x0b\x32<.systemathics.apis.services.daily.v2.DailyScalarStreamFieldsH\x00R\x04info\x12P\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32:.systemathics.apis.services.daily.v2.DailyScalarStreamItemH\x00R\x04\x64\x61taB\t\n\x07payload\"1\n\x17\x44\x61ilyScalarStreamFields\x12\x16\n\x06\x66ields\x18\x01 \x03(\tR\x06\x66ields\"R\n\x15\x44\x61ilyScalarStreamItem\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta\"\x81\x01\n DailyScalarAssetProviderResponse\x12]\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32I.systemathics.apis.services.daily.v2.DailyScalarAssetProviderItemResponseR\x04\x64\x61ta\"\x8e\x01\n$DailyScalarAssetProviderItemResponse\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\"s\n\x19\x44\x61ilyScalarFieldsResponse\x12V\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x42.systemathics.apis.services.daily.v2.DailyScalarFieldsItemResponseR\x04\x64\x61ta\"\x9f\x01\n\x1d\x44\x61ilyScalarFieldsItemResponse\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields2\x95\x05\n\x12\x44\x61ilyScalarService\x12\x9b\x01\n\x0b\x44\x61ilyScalar\x12\x37.systemathics.apis.services.daily.v2.DailyScalarRequest\x1a\x38.systemathics.apis.services.daily.v2.DailyScalarResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v2/daily_scalar/\x12\xb0\x01\n\x11\x44\x61ilyScalarStream\x12\x37.systemathics.apis.services.daily.v2.DailyScalarRequest\x1a>.systemathics.apis.services.daily.v2.DailyScalarStreamResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v2/daily_scalar_stream/0\x01\x12\x8d\x01\n\x11\x44\x61ilyScalarFields\x12\x16.google.protobuf.Empty\x1a>.systemathics.apis.services.daily.v2.DailyScalarFieldsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v2/daily_scalar_fields/\x12\x9d\x01\n\x18\x44\x61ilyScalarAssetProvider\x12\x16.google.protobuf.Empty\x1a\x45.systemathics.apis.services.daily.v2.DailyScalarAssetProviderResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v2/daily_scalar_provider/B\xef\x01\n\'com.systemathics.apis.services.daily.v2B\x13GetDailyScalarProtoP\x01\xa2\x02\x04SASD\xaa\x02#Systemathics.Apis.Services.Daily.V2\xca\x02#Systemathics\\Apis\\Services\\Daily\\V2\xe2\x02/Systemathics\\Apis\\Services\\Daily\\V2\\GPBMetadata\xea\x02\'Systemathics::Apis::Services::Daily::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily.v2.get_daily_scalar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.systemathics.apis.services.daily.v2B\023GetDailyScalarProtoP\001\242\002\004SASD\252\002#Systemathics.Apis.Services.Daily.V2\312\002#Systemathics\\Apis\\Services\\Daily\\V2\342\002/Systemathics\\Apis\\Services\\Daily\\V2\\GPBMetadata\352\002\'Systemathics::Apis::Services::Daily::V2'
  _globals['_DAILYSCALARRESPONSE_FIELDSDATAENTRY']._options = None
  _globals['_DAILYSCALARRESPONSE_FIELDSDATAENTRY']._serialized_options = b'8\001'
  _globals['_DAILYSCALARSERVICE'].methods_by_name['DailyScalar']._options = None
  _globals['_DAILYSCALARSERVICE'].methods_by_name['DailyScalar']._serialized_options = b'\202\323\344\223\002\023\022\021/v2/daily_scalar/'
  _globals['_DAILYSCALARSERVICE'].methods_by_name['DailyScalarStream']._options = None
  _globals['_DAILYSCALARSERVICE'].methods_by_name['DailyScalarStream']._serialized_options = b'\202\323\344\223\002\032\022\030/v2/daily_scalar_stream/'
  _globals['_DAILYSCALARSERVICE'].methods_by_name['DailyScalarFields']._options = None
  _globals['_DAILYSCALARSERVICE'].methods_by_name['DailyScalarFields']._serialized_options = b'\202\323\344\223\002\032\022\030/v2/daily_scalar_fields/'
  _globals['_DAILYSCALARSERVICE'].methods_by_name['DailyScalarAssetProvider']._options = None
  _globals['_DAILYSCALARSERVICE'].methods_by_name['DailyScalarAssetProvider']._serialized_options = b'\202\323\344\223\002\034\022\032/v2/daily_scalar_provider/'
  _globals['_DAILYSCALARREQUEST']._serialized_start=334
  _globals['_DAILYSCALARREQUEST']._serialized_end=575
  _globals['_DAILYSCALARRESPONSE']._serialized_start=578
  _globals['_DAILYSCALARRESPONSE']._serialized_end=873
  _globals['_DAILYSCALARRESPONSE_FIELDSDATAENTRY']._serialized_start=749
  _globals['_DAILYSCALARRESPONSE_FIELDSDATAENTRY']._serialized_end=873
  _globals['_DAILYSCALARVALUERESPONSE']._serialized_start=875
  _globals['_DAILYSCALARVALUERESPONSE']._serialized_end=921
  _globals['_DAILYSCALARSTREAMRESPONSE']._serialized_start=924
  _globals['_DAILYSCALARSTREAMRESPONSE']._serialized_end=1128
  _globals['_DAILYSCALARSTREAMFIELDS']._serialized_start=1130
  _globals['_DAILYSCALARSTREAMFIELDS']._serialized_end=1179
  _globals['_DAILYSCALARSTREAMITEM']._serialized_start=1181
  _globals['_DAILYSCALARSTREAMITEM']._serialized_end=1263
  _globals['_DAILYSCALARASSETPROVIDERRESPONSE']._serialized_start=1266
  _globals['_DAILYSCALARASSETPROVIDERRESPONSE']._serialized_end=1395
  _globals['_DAILYSCALARASSETPROVIDERITEMRESPONSE']._serialized_start=1398
  _globals['_DAILYSCALARASSETPROVIDERITEMRESPONSE']._serialized_end=1540
  _globals['_DAILYSCALARFIELDSRESPONSE']._serialized_start=1542
  _globals['_DAILYSCALARFIELDSRESPONSE']._serialized_end=1657
  _globals['_DAILYSCALARFIELDSITEMRESPONSE']._serialized_start=1660
  _globals['_DAILYSCALARFIELDSITEMRESPONSE']._serialized_end=1819
  _globals['_DAILYSCALARSERVICE']._serialized_start=1822
  _globals['_DAILYSCALARSERVICE']._serialized_end=2483
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.daily.v2 import get_daily_scalar_pb2 as systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2


class DailyScalarServiceStub(object):
    """Called to request daily prices data. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DailyScalar = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalar',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarResponse.FromString,
                )
        self.DailyScalarStream = channel.unary_stream(
                '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalarStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarStreamResponse.FromString,
                )
        self.DailyScalarFields = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalarFields',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarFieldsResponse.FromString,
                )
        self.DailyScalarAssetProvider = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalarAssetProvider',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarAssetProviderResponse.FromString,
                )


class DailyScalarServiceServicer(object):
    """Called to request daily prices data. 
    """

    def DailyScalar(self, request, context):
        """Gets daily historical data timeseries by identifier
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DailyScalarStream(self, request, context):
        """Gets daily historical data timeseries by identifier using streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DailyScalarFields(self, request, context):
        """Gets daily historical data by date
        rpc DailyByDate(DailyDateRequest) returns (stream GetDailyByDateResponse)
        {
        option (google.api.http) = {
        		get: "/v2/daily_date/"
        };
        }

        Gets all available fields by asset and provider.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DailyScalarAssetProvider(self, request, context):
        """Gets all available provider by asset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DailyScalarServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DailyScalar': grpc.unary_unary_rpc_method_handler(
                    servicer.DailyScalar,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarResponse.SerializeToString,
            ),
            'DailyScalarStream': grpc.unary_stream_rpc_method_handler(
                    servicer.DailyScalarStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarStreamResponse.SerializeToString,
            ),
            'DailyScalarFields': grpc.unary_unary_rpc_method_handler(
                    servicer.DailyScalarFields,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarFieldsResponse.SerializeToString,
            ),
            'DailyScalarAssetProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.DailyScalarAssetProvider,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarAssetProviderResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.daily.v2.DailyScalarService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DailyScalarService(object):
    """Called to request daily prices data. 
    """

    @staticmethod
    def DailyScalar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalar',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DailyScalarStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalarStream',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DailyScalarFields(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalarFields',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarFieldsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DailyScalarAssetProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalarAssetProvider',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarAssetProviderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
